@@ -36,4 +36,5 @@ void		 fu_usb_device_set_dev			(FuUsbDevice	*device,
 							 GUsbDevice	*usb_device);
 gboolean	 fu_usb_device_is_open			(FuUsbDevice	*device);
 GUdevDevice	*fu_usb_device_find_udev_device		(FuUsbDevice	*device,
-							 GError		**error);
+							 GError		**error)
+							 G_GNUC_WARN_UNUSED_RESULT;
